#!/usr/bin/perl -w

###
# Pod Documentation
###

=head1 NAME

rate4site_bootstrap.perl

=head1 SYNOPSIS

Usage: rate4site_bootstrap.perl -i <path/to/input/file/of/alignments> -o <path/to/output/stockholm/file>

Runs rate4site on a set of bootstrap samples. Warning: created a bunch of files in the working directory.

=head1 DESCRIPTION

=over

=item B<-i> <file path> 

Output of seqboot program from Phylip. Concatenated alignments.

=item B<-o> <file path> 

Output concatenated tree file, suitable for input into the Phylip consensus program.

=back

=head1 AUTHOR

Jeffrey Barrick

=head1 COPYRIGHT

Copyright 2005.  All rights reserved.

=cut

###
# End Pod Documentation
###

use strict;

use FindBin;
use lib $FindBin::Bin;
use Xgrid::Submitter;

#Get options
use Getopt::Long;
use Pod::Usage;
my ($help, $man);
my ($input_file, $output_file);
#pod2usage(1) if (scalar @ARGV == 0);
GetOptions(
	'help|?' => \$help, 'man' => \$man,
	'in|i=s' => \$input_file,
	'out|o=s' => \$output_file
) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-exitstatus => 0, -verbose => 2) if $man;
pod2usage(1) if (!defined $input_file || !defined $output_file);


#Split out the main file into many files (named "input_#.phylip")

open IN, "$input_file";

mkdir "input";
my $i = 0;
my $phylip_file;
while (<IN>)
{
	if ($_ =~ m/\d+\s+\d+/)
	{
		$i++;
		open $phylip_file, ">input/$i.phylip";
	}
	print $phylip_file $_;
}


mkdir "result";
mkdir "tree";
mkdir "output";
mkdir "result_unnormalized";

chdir "input";
#Run rate4site on each input file
my $blast_xs = new Xgrid::Submitter( 
				stdin_arg => 1,
				command => 'rate4site', 
				args => "-s STDIN -o ../result/STDIN.res -x ../tree/STDIN.tree -y ../result_unnormalized/STDIN.res -ib -mn -zj -k 16",
				si => [ "." ] ,
				so => "../output",
				no_xgrid => 1,
				);

$blast_xs->print();

$blast_xs->submit();


#Cat tree files

chdir "..";
system "cat tree/* > $output_file";
